widening_mul_fixed

Function widening_mul_fixed 

pub const fn widening_mul_fixed<const LHS: usize, const RHS: usize>(
    lhs: &UintRef,
    rhs: &UintRef,
) -> (Uint<LHS>, Uint<RHS>)
Compute a wide multiplication result for fixed-size arguments. Common power-of-two limb counts are implemented explicitly and used as a basis for general multiplication.

The limb counts of lhs and rhs must be LHS and RHS respectively.