wrapping_square

Function wrapping_square 

pub(crate) const fn wrapping_square(uint: &UintRef, out: &mut UintRef) -> Limb
Square a limb slice, placing the potentially-truncated result in out.

out must have a limb count less than or equal to the width of the wide squaring of uint.