pub const fn wrapping_mul_fixed<const LHS: usize>(
lhs: &UintRef,
rhs: &UintRef,
) -> (Uint<LHS>, Limb)Expand description
Compute a wrapping multiplication result for a fixed LHS and dynamic RHS argument. Common power-of-two limb counts are implemented explicitly and used as a basis for general multiplication.
The limb count of lhs must be LHS.