pub const fn wrapping_square_fixed<const LIMBS: usize>(
uint: &UintRef,
) -> (Uint<LIMBS>, Limb)Expand description
Compute a wrapping square for a fixed-size argument. This method defers to the dynamic implementation, but inlining results in the selection of an efficient algorithm.
The limb count of uint must be LIMBS.